bayespy.inference.vmp.nodes.deterministic.Deterministic.get_moments
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.get_moments